package com.siwei.rsmonitoring.mapper;

import java.util.List;
import com.siwei.rsmonitoring.domain.TDkAuditflowStep;

/**
 * 地块的审核流程步骤Mapper接口
 * 
 * @author siwei
 * @date 2025-01-20
 */
public interface TDkAuditflowStepMapper 
{
    /**
     * 查询地块的审核流程步骤
     * 
     * @param id 地块的审核流程步骤主键
     * @return 地块的审核流程步骤
     */
    public TDkAuditflowStep selectTDkAuditflowStepById(String id);

    /**
     * 查询地块的审核流程步骤列表
     * 
     * @param tDkAuditflowStep 地块的审核流程步骤
     * @return 地块的审核流程步骤集合
     */
    public List<TDkAuditflowStep> selectTDkAuditflowStepList(TDkAuditflowStep tDkAuditflowStep);

    /**
     * 新增地块的审核流程步骤
     * 
     * @param tDkAuditflowStep 地块的审核流程步骤
     * @return 结果
     */
    public int insertTDkAuditflowStep(TDkAuditflowStep tDkAuditflowStep);

    /**
     * 修改地块的审核流程步骤
     * 
     * @param tDkAuditflowStep 地块的审核流程步骤
     * @return 结果
     */
    public int updateTDkAuditflowStep(TDkAuditflowStep tDkAuditflowStep);

    /**
     * 删除地块的审核流程步骤
     * 
     * @param id 地块的审核流程步骤主键
     * @return 结果
     */
    public int deleteTDkAuditflowStepById(String id);

    /**
     * 批量删除地块的审核流程步骤
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTDkAuditflowStepByIds(String[] ids);
}
